[![Tests](https://github.com/timothymeyers/azure-data-scraper/actions/workflows/unit-test.yml/badge.svg)](https://github.com/timothymeyers/azure-data-scraper/actions/workflows/unit-test.yml)


# azure-data-scraper
tbd